<?php

/**
 * Yii Framework FriendlyUrl Extension
 * @package FriendlyURL
 * @license BSD
 */

/**
 * Page representative class.
 * @package FriendlyURL
 * @author Oleg Blednov aka Blake-R
 * @version 2009-04-13
 */

class CFriendlyUrlPage
{
	/**
	 * Internal counter for generate {@link $uniqueId}.
	 * @var integer
	 */
	static protected $id_count = 1;

	/**
	 * Unique ID, generated automatically on create pages hierarchi.
	 * @var integer
	 */
	protected $uniqueId;
	/**
	 * Page ID for designate belonging data to this page.
	 * @var integer
	 */
	protected $pageId;
	/**
	 * Automatically generated parent page.
	 * @var CFriendlyUrlPage
	 */
	protected $parent;
	/**
	 * Parently-unique page name.
	 * @var string
	 */
	protected $cname;
	/**
	 * Controller name for page. May also contain action name: ControllerID/ActionID
	 * @var string
	 */
	protected $controller;
	/**
	 * Page title. May contain {@link CFriendlyUrlHelper::magicString()
	 * magicString} for evaluation, started with '@@'.
	 * @var string
	 */
	protected $pageTitle;
	/**
	 * Menu title or NULL, if not showing in menu. May contain
	 * {@link CFriendlyUrlHelper::magicString() magicString} for evaluation,
	 * started with '@@'.
	 * @var string
	 */
	protected $menuTitle;
	/**
	 * Child pages.
	 * @var array
	 */
	protected $children;

	/**
	 * Create new page representation.
	 * @param integer $pageId Page ID.
	 * @param string $cname Parently-unique page name.
	 * @param string $controller Controller name.
	 * @param string $pageTitle Page title.
	 * @param string $menuTitle Menu title.
	 * @param array $children Children elements.
	 * @uses $children
	 * @uses $cname
	 * @uses $controller
	 * @uses CFriendlyUrlPage::$id_count
	 * @uses $menuTitle
	 * @uses $pageId
	 * @uses $pageTitle
	 * @uses CFriendlyUrlPage::$parent
	 * @uses $uniqueId
	 */
	public function __construct($pageId, $cname, $controller, $pageTitle, $menuTitle, array $children=array())
	{
		$this->uniqueId = self::$id_count++;
		$this->pageId = $pageId;
		$this->cname = $cname;
		$this->controller = $controller;
		$this->pageTitle = $pageTitle;
		$this->menuTitle = $menuTitle;
		$this->children = $children;

		foreach ($this->children as $child)
		{
			$child->parent = $this;
		}
	}

	/**
	 * Make class variables read-only.
	 * @param string $name Name of the variable.
	 * @return mixed Value of variable.
	 */
	public function __get($name)
	{
		return $this->$name;
	}
}

?>
