<?php

/**
 * Yii Framework FriendlyUrl Extension
 * @package FriendlyURL
 * @license BSD
 */

/**
 * DB pages storage class.
 * @package FriendlyURL
 * @author Oleg Blednov aka Blake-R
 * @version 2009-04-13
 */
class CFriendlyUrlPageDbStorage implements IFriendlyUrlPageStorage
{
	/**
	 * Table, in which pages data stored.
	 * @var string
	 */
	protected $dataTable = 'Pages';

	/**
	 * Internal pages data.
	 * @var array
	 */
	protected $dbData;

	/**
	 * Constructor.
	 * @param array $params Parameters for initialization.
	 * @uses $dataTable
	 * @see IFriendlyUrlPageStorage::__construct()
	 */
	public function __construct(array $params)
	{
		if (isset($params['dataTable'])) $this->dataTable = $params['dataTable'];
	}

	/**
	 * Getting pages data.
	 * @return array All pages in array.
	 * @uses $dbData
	 * @uses getSubData()
	 * @uses CDbCommand::queryAll()
	 * @uses CDbConnection::createCommand()
	 * @see IFriendlyUrlPageStorage::getData()
	 * @link http://www.yiiframework.com/doc/api/CDbCommand#queryAll-detail CDbCommand::queryAll()
	 * @link http://www.yiiframework.com/doc/api/CDbConnection#createCommand-detail CDbConnection::createCommand()
	 */
	public function getData()
	{
		$query =
			"SELECT id, pageId, parentId, cname, controller, pageTitle, menuTitle ".
			"FROM `{$this->dataTable}` ".
			"ORDER BY parentId, priority";
		$this->dbData = Yii::app()->db->createCommand($query)->queryAll();

		return $this->getSubData();
	}

	/**
	 * Walk through internal pages data and build right pages structure.
	 * @param integer $parentId ID of parent element.
	 * @return array Pages data.
	 * @uses $dbData
	 * @uses getSubData()
	 * @uses CFriendlyUrlPage::__construct()
	 */
	protected function getSubData($parentId=0)
	{
		$data = array();
		foreach ($this->dbData as $key=>$row)
		{
			if ($row['parentId']==$parentId)
			{
				unset($this->dbData[$key]);
				array_push($data, new CFriendlyUrlPage(
					$row['pageId'],
					$row['cname'],
					$row['controller'],
					$row['pageTitle'],
					$row['menuTitle'],
					$this->getSubData($row['id'])));
			}
		}
		return $data;
	}
}

?>
